@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.95 2009/08/28 00:40:00 bowkenken Exp $
+* $Id: amenu.c,v 1.97 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -871,7 +871,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'W';
 		p[k].short_key[0] = '\0';
-		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY_L,
 				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_copy_large;
 		p[k].arg = (void *)i;
@@ -883,7 +883,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'Y';
 		p[k].short_key[0] = '\0';
-		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE_L,
 				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_paste_large;
 		p[k].arg = (void *)i;
