@@ -85,8 +85,10 @@ void	call_demo_ending_skip_scene( void );
 void	call_game_music_play_scene( bool_t flg_gui );
 void	call_game_music_play( long kind, long idx );
 void	call_game_music_replay( void );
+void	call_game_music_set_volume( rate_t rate );
 void	call_game_sound_play( long kind, long n );
 void	call_game_sound_stop( void );
+void	call_game_sound_set_volume( rate_t rate );
 long	call_game_joystick_get_joy( void );
 void	call_game_joystick_sel_joy( long n );
 const char	*call_game_joystick_get_name( long n );
