@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.109 2009/08/08 19:01:31 bowkenken Exp $
+* $Id: call.cpp,v 1.116 2010/01/12 04:09:54 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -35,6 +35,10 @@
 extern WSCwindow *StatWin;
 #endif
 
+#ifdef D_GTK
+static GStaticMutex	g_key_buf_mutex = G_STATIC_MUTEX_INIT;
+#endif // D_GTK
+
 static long g_joy_n = 0;
 static joy_kind_t g_joy_kind = JOY_KIND_PS;
 
@@ -80,6 +84,28 @@ void	gui_end( void )
 #endif // D_MFC
 }
 
+/***************************************************************
+* ХåեΥå
+***************************************************************/
+
+void	key_buf_lock( void )
+{
+#ifdef D_GTK
+	g_static_mutex_lock( &g_key_buf_mutex );
+#endif // D_GTK
+}
+
+/***************************************************************
+* ХåեΥå
+***************************************************************/
+
+void	key_buf_unlock( void )
+{
+#ifdef D_GTK
+	g_static_mutex_unlock( &g_key_buf_mutex );
+#endif // D_GTK
+}
+
 /***************************************************************
 * ᥤ󡦥롼פΥåɤڤ
 * void *(*func)( void * ) : 롦Хåؿ
@@ -1067,7 +1093,13 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 long	call_pcg_dun_get_crsr_width( bool_t flagSub )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.getCrsrWidth( !!flagSub );
+	gui_begin();
+
+	long n = gPcgDun.getCrsrWidth( !!flagSub );
+
+	gui_end();
+
+	return n;
 #endif
 
 	return 0;
@@ -1082,7 +1114,13 @@ long	call_pcg_dun_get_crsr_width( bool_t flagSub )
 long	call_pcg_dun_get_crsr_height( bool_t flagSub )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.getCrsrHeight( !!flagSub );
+	gui_begin();
+
+	long n = gPcgDun.getCrsrHeight( !!flagSub );
+
+	gui_end();
+
+	return n;
 #endif
 
 	return 0;
@@ -1111,11 +1149,15 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 			return get_chr_left( chr->x, chr->dx );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeX();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1148,11 +1190,15 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 			return get_chr_right( chr->x, chr->dx );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1185,11 +1231,15 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 			return get_chr_top( chr->y, chr->dy );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeY();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1222,11 +1272,15 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 			return get_chr_bottom( chr->y, chr->dy );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1240,13 +1294,22 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 * ɸޥåסɥɽϰ⤫Ĵ٤
 * long mapX : Xɸ
 * long mapY : Yɸ
+* bool_t flg_gui : GUI ƤФ줿?
 * return : ޥåסɥɽϰ⤫?
 ***************************************************************/
 
-bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
+bool_t	call_pcg_dun_clip_win( long mapX, long mapY, bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.clipWin( mapX, mapY );
+	if( !flg_gui )
+		gui_begin();
+
+	bool_t flg = gPcgDun.clipWin( mapX, mapY );
+
+	if( !flg_gui )
+		gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
@@ -1258,10 +1321,18 @@ bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
 * return : ޥåסɥɽϰ⤫?
 ***************************************************************/
 
-bool_t	call_pcg_dun_clip_win_x( long mapX )
+bool_t	call_pcg_dun_clip_win_x( long mapX, bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.clipWinX( mapX );
+	if( !flg_gui )
+		gui_begin();
+
+	bool_t flg = gPcgDun.clipWinX( mapX );
+
+	if( !flg_gui )
+		gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
@@ -1273,18 +1344,25 @@ bool_t	call_pcg_dun_clip_win_x( long mapX )
 * return : ޥåסɥɽϰ⤫?
 ***************************************************************/
 
-bool_t	call_pcg_dun_clip_win_y( long mapY )
+bool_t	call_pcg_dun_clip_win_y( long mapY, bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.clipWinY( mapY );
+	if( !flg_gui )
+		gui_begin();
+
+	bool_t flg = gPcgDun.clipWinY( mapY );
+
+	if( !flg_gui )
+		gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
 }
 
 /***************************************************************
-* 饹ܥΥǥ⤬äĴ٤
-* return : ǥ⤬ä?
+* 饹ܥΥǥꥻå
 ***************************************************************/
 
 void	call_demo_last_boss_reset( void )
@@ -1319,18 +1397,58 @@ bool_t	call_demo_last_boss_check_done( void )
 	if( !g_flg_gui )
 		return TRUE;
 
-	if( gPcgDun.pDemoLastBoss == NULL )
-		return TRUE;
+	bool_t	flg = TRUE;
 
-	if( gPcgDun.pDemoLastBoss->checkDone() )
-		return TRUE;
-	else
-		return FALSE;
+	// gui_begin();
+
+	do {
+		if( gPcgDun.pDemoLastBoss == NULL ){
+			flg = TRUE;
+			break;
+		}
+
+		if( gPcgDun.pDemoLastBoss->checkDone() ){
+			flg = TRUE;
+			break;
+		} else {
+			flg = FALSE;
+			break;
+		}
+
+		break;
+	} while( 0 );
+
+	// gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
 }
 
+/***************************************************************
+* ǥ󥰤Υ򥹥å
+***************************************************************/
+
+void	call_demo_ending_skip_scene( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	if( gPcgDun.pDemoEnding == NULL )
+		return;
+
+	gui_begin();
+
+	gPcgDun.pDemoEnding->skipScene();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ˹礻 BGM κ
 * bool_t flg_gui : GUI ƤФ줿?
@@ -1381,6 +1499,24 @@ void	call_game_music_replay( void )
 #endif
 }
 
+/***************************************************************
+* BGM β̤
+***************************************************************/
+
+void	call_game_music_set_volume( rate_t rate )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+
+	gui_begin();
+
+	gMusic.setVolume( rate );
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * SE κ
 * sound_kind_t kind : SE μ
@@ -1413,6 +1549,24 @@ void	call_game_sound_stop( void )
 #endif
 }
 
+/***************************************************************
+* SE β̤
+***************************************************************/
+
+void	call_game_sound_set_volume( rate_t rate )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+
+	gui_begin();
+
+	gSound.setVolume( rate );
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * Υ祤ƥåֹ֤
 * return : 祤ƥåֹ
