@@ -218,11 +218,13 @@ long	read_ctrl( long *p );
 long	read_esc( long *p );
 char	*get_reg_macro( void );
 void	set_reg_macro( bool_t flg );
+void	reg_macro_str( const char *s );
 void	reg_macro( long c );
 void	draw_replay( bool_t flg_redraw );
 bool_t	get_key_pos( pos_t *pos );
 long	get_key_num( void );
 void	un_get_key( long c );
+long	get_key_no_null( bool_t flg_clr_key_buf );
 long	get_key( bool_t flg_clr_key_buf );
 void	get_key_wait_cancel( bool_t flg_clr_key_buf );
 void	get_key_wait_cancel_or_exec( bool_t flg_clr_key_buf );
@@ -240,11 +242,21 @@ long	get_key_no_clr_default( bool_t *p_flg_cont_exec );
 long	get_key_no_wait( void );
 bool_t	chk_key_buf( void );
 long	get_key_buf_char( void );
+long	get_key_n( const char *p );
+long	get_key_n_all( const char *p );
+long	get_key_n_func( const char *p );
+long	get_key_n_mouse( const char *p );
+long	get_key_n_joystick( const char *p );
+long	get_key_n_num( const char *p );
+long	get_key_n_hex_dec( const char *p );
+long	get_key_n_dec( const char *p );
+long	get_key_n_oct( const char *p );
 long	get_key_buf_char_sub( void );
 bool_t	set_key_buf_char_head( long c );
 bool_t	set_key_buf_char_tail( long c );
 bool_t	set_key_buf_str_head( const char *s );
 bool_t	set_key_buf_str_tail( const char *s );
+bool_t	cv_key_buf_char_tail( long dst, long src );
 long	get_key_tab_n( const char *key );
 char	*get_key_tab_cmd( const char *key );
 char	*get_key_tab_cmd_char( long c );
@@ -253,6 +265,7 @@ void	set_key_tab( const char *key, const char *str );
 void	set_key_tab_char( long c, const char *str );
 long	*get_clk_tck( void );
 bool_t	get_flg_draw_menu( void );
+void	check_memory_draw_c( void );
 
 #ifdef __cplusplus
 }
