@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.17 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: draw-tab.h,v 1.25 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_TAB_H
@@ -65,11 +65,11 @@
 
 #define	WIN_STAT_ACT_DRAW_MIN_X	(WIN_STAT_NAME_DRAW_WIDTH + 1)
 #define	WIN_STAT_ACT_DRAW_MIN_Y	0
-#define	WIN_STAT_ACT_DRAW_WIDTH	(39 - WIN_STAT_NAME_DRAW_WIDTH - 1)
+#define	WIN_STAT_ACT_DRAW_WIDTH	(38 - WIN_STAT_NAME_DRAW_WIDTH - 1)
 
 #define	WIN_STAT_COND_DRAW_MIN_X	(WIN_STAT_HP_DRAW_WIDTH + 1)
 #define	WIN_STAT_COND_DRAW_MIN_Y	1
-#define	WIN_STAT_COND_DRAW_WIDTH	(39 - WIN_STAT_HP_DRAW_WIDTH - 1)
+#define	WIN_STAT_COND_DRAW_WIDTH	(38 - WIN_STAT_HP_DRAW_WIDTH - 1)
 
 #define	WIN_STAT_DUN_LEV_DRAW_MIN_X	0
 #define	WIN_STAT_DUN_LEV_DRAW_MIN_Y	0
@@ -83,7 +83,7 @@
 
 #define	WIN_MBR_DATA_DRAW_MID_X	41
 
-/* page 1/4 */
+/* page 1/6 */
 
 #define	WIN_MBR_DATA_NAME_TTL_DRAW_MIN_X	0
 #define	WIN_MBR_DATA_NAME_TTL_DRAW_MIN_Y	0
@@ -270,18 +270,23 @@
 #define	WIN_MBR_DATA_STORE_LIGHT_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 11 + 1)
 
-/* page 2/4 */
+#define	WIN_MBR_DATA_GRAPH_FILE_DRAW_MIN_X	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+#define	WIN_MBR_DATA_GRAPH_FILE_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 12 + 2)
+
+/* page 2/6 */
 
 /* lev left */
 
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_X	(0 + 4)
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y	2
 
-#define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 20)
+#define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 18)
 #define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y
 
-#define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 27)
+#define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 25)
 #define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y
 
@@ -292,12 +297,12 @@
 #define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y	2
 
 #define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_X	\
-		(WIN_MBR_DATA_DRAW_MID_X + 20)
+		(WIN_MBR_DATA_DRAW_MID_X + 18)
 #define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y
 
 #define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_X	\
-		(WIN_MBR_DATA_DRAW_MID_X + 27)
+		(WIN_MBR_DATA_DRAW_MID_X + 25)
 #define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_Y
 
@@ -474,7 +479,54 @@
 #define	WIN_MBR_DATA_NIN_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y + 12)
 
-/* page 3/4 4/4 */
+/* page 3/6 4/6 */
+
+/* skill title */
+
+#define	WIN_MBR_DATA_SKILL_NAME_TTL_DRAW_MIN_X	0
+#define	WIN_MBR_DATA_SKILL_NAME_TTL_DRAW_MIN_Y	2
+
+#define	WIN_MBR_DATA_SKILL_LEV_TTL_DRAW_MIN_X	\
+		(WIN_MBR_DATA_DRAW_MID_X + 4)
+#define	WIN_MBR_DATA_SKILL_LEV_TTL_DRAW_MIN_Y	\
+		WIN_MBR_DATA_SKILL_NAME_TTL_DRAW_MIN_Y
+
+#define	WIN_MBR_DATA_SKILL_EXP_TTL_DRAW_MIN_X	\
+		(WIN_MBR_DATA_DRAW_MID_X + 18)
+#define	WIN_MBR_DATA_SKILL_EXP_TTL_DRAW_MIN_Y	\
+		WIN_MBR_DATA_SKILL_LEV_TTL_DRAW_MIN_Y
+
+#define	WIN_MBR_DATA_SKILL_NEED_EXP_TTL_DRAW_MIN_X	\
+		(WIN_MBR_DATA_DRAW_MID_X + 25)
+#define	WIN_MBR_DATA_SKILL_NEED_EXP_TTL_DRAW_MIN_Y	\
+		WIN_MBR_DATA_SKILL_LEV_TTL_DRAW_MIN_Y
+
+/* skill */
+
+#define	WIN_MBR_DATA_SKILL_NAME_DRAW_MIN_X	0
+#define	WIN_MBR_DATA_SKILL_NAME_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_SKILL_NAME_TTL_DRAW_MIN_Y + 1)
+
+#define	WIN_MBR_DATA_SKILL_LEV_DRAW_MIN_X	\
+		(WIN_MBR_DATA_DRAW_MID_X + 4 + 2)
+#define	WIN_MBR_DATA_SKILL_LEV_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_SKILL_LEV_TTL_DRAW_MIN_Y + 1)
+
+#define	WIN_MBR_DATA_SKILL_EXP_DRAW_MIN_X	\
+		(WIN_MBR_DATA_DRAW_MID_X + 39 - 11 - 10 - 3)
+#define	WIN_MBR_DATA_SKILL_EXP_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_SKILL_EXP_TTL_DRAW_MIN_Y + 1)
+
+#define	WIN_MBR_DATA_SKILL_NEED_EXP_DRAW_MIN_X	\
+		(WIN_MBR_DATA_DRAW_MID_X + 39 - 10 - 3)
+#define	WIN_MBR_DATA_SKILL_NEED_EXP_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_SKILL_NEED_EXP_TTL_DRAW_MIN_Y + 1)
+
+#define	WIN_MBR_DATA_SKILL_HINT_DRAW_MIN_X	0
+#define	WIN_MBR_DATA_SKILL_HINT_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_SKILL_NAME_DRAW_MIN_Y + 10 + 2)
+
+/* page 5/6 6/6 */
 
 #define	WIN_MBR_DATA_ITEM_DRAW_MIN_X	\
 		WIN_MBR_DATA_NAME_TTL_DRAW_MIN_X
@@ -483,6 +535,8 @@
 
 /* Page */
 
+#define	WIN_MBR_DATA_SWAP_PAGE_MBR_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
+#define	WIN_MBR_DATA_SWAP_PAGE_MBR_DRAW_MIN_Y	17
 #define	WIN_MBR_DATA_PREV_PAGE_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
 #define	WIN_MBR_DATA_PREV_PAGE_DRAW_MIN_Y	18
 #define	WIN_MBR_DATA_NEXT_PAGE_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
@@ -530,6 +584,8 @@ bool_t	flg_mbr_data_draw_v_line[MBR_DATA_PAGE_MAX_N] = {
 	TRUE,
 	FALSE,
 	FALSE,
+	FALSE,
+	FALSE,
 };
 
 /* СǡΥǥݥȽ */
@@ -583,6 +639,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 		FALSE,	/* DATA_N_STORE_LIGHT, */
+		TRUE,	/* DATA_N_GRAPH_FILE, */
 
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
@@ -633,6 +690,34 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
+		FALSE,	/* DATA_N_SKILL_NAME_A, */
+		FALSE,	/* DATA_N_SKILL_NAME_B, */
+		FALSE,	/* DATA_N_SKILL_LEV, */
+		FALSE,	/* DATA_N_SKILL_EXP, */
+		FALSE,	/* DATA_N_SKILL_NEED_EXP, */
+
+		TRUE,	/* DATA_N_SKILL_A_00, */
+		TRUE,	/* DATA_N_SKILL_A_01, */
+		TRUE,	/* DATA_N_SKILL_A_02, */
+		TRUE,	/* DATA_N_SKILL_A_03, */
+		TRUE,	/* DATA_N_SKILL_A_04, */
+		TRUE,	/* DATA_N_SKILL_A_05, */
+		TRUE,	/* DATA_N_SKILL_A_06, */
+		TRUE,	/* DATA_N_SKILL_A_07, */
+		TRUE,	/* DATA_N_SKILL_A_08, */
+		TRUE,	/* DATA_N_SKILL_A_09, */
+
+		TRUE,	/* DATA_N_SKILL_B_00, */
+		TRUE,	/* DATA_N_SKILL_B_01, */
+		TRUE,	/* DATA_N_SKILL_B_02, */
+		TRUE,	/* DATA_N_SKILL_B_03, */
+		TRUE,	/* DATA_N_SKILL_B_04, */
+		TRUE,	/* DATA_N_SKILL_B_05, */
+		TRUE,	/* DATA_N_SKILL_B_06, */
+		TRUE,	/* DATA_N_SKILL_B_07, */
+		TRUE,	/* DATA_N_SKILL_B_08, */
+		TRUE,	/* DATA_N_SKILL_B_09, */
+
 		TRUE,	/* DATA_N_ITEM_00, */
 		TRUE,	/* DATA_N_ITEM_01, */
 		TRUE,	/* DATA_N_ITEM_02, */
@@ -664,6 +749,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		TRUE,	/* DATA_N_EQUIP_FEET, */
 		TRUE,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
 
+		TRUE,	/* DATA_N_SWAP_PAGE_MBR, */
 		TRUE,	/* DATA_N_PREV_PAGE, */
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
@@ -715,6 +801,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 		FALSE,	/* DATA_N_STORE_LIGHT, */
+		TRUE,	/* DATA_N_GRAPH_FILE, */
 
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
@@ -765,6 +852,34 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
+		FALSE,	/* DATA_N_SKILL_NAME_A, */
+		FALSE,	/* DATA_N_SKILL_NAME_B, */
+		FALSE,	/* DATA_N_SKILL_LEV, */
+		FALSE,	/* DATA_N_SKILL_EXP, */
+		FALSE,	/* DATA_N_SKILL_NEED_EXP, */
+
+		TRUE,	/* DATA_N_SKILL_A_00, */
+		TRUE,	/* DATA_N_SKILL_A_01, */
+		TRUE,	/* DATA_N_SKILL_A_02, */
+		TRUE,	/* DATA_N_SKILL_A_03, */
+		TRUE,	/* DATA_N_SKILL_A_04, */
+		TRUE,	/* DATA_N_SKILL_A_05, */
+		TRUE,	/* DATA_N_SKILL_A_06, */
+		TRUE,	/* DATA_N_SKILL_A_07, */
+		TRUE,	/* DATA_N_SKILL_A_08, */
+		TRUE,	/* DATA_N_SKILL_A_09, */
+
+		TRUE,	/* DATA_N_SKILL_B_00, */
+		TRUE,	/* DATA_N_SKILL_B_01, */
+		TRUE,	/* DATA_N_SKILL_B_02, */
+		TRUE,	/* DATA_N_SKILL_B_03, */
+		TRUE,	/* DATA_N_SKILL_B_04, */
+		TRUE,	/* DATA_N_SKILL_B_05, */
+		TRUE,	/* DATA_N_SKILL_B_06, */
+		TRUE,	/* DATA_N_SKILL_B_07, */
+		TRUE,	/* DATA_N_SKILL_B_08, */
+		TRUE,	/* DATA_N_SKILL_B_09, */
+
 		TRUE,	/* DATA_N_ITEM_00, */
 		TRUE,	/* DATA_N_ITEM_01, */
 		TRUE,	/* DATA_N_ITEM_02, */
@@ -796,6 +911,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		TRUE,	/* DATA_N_EQUIP_FEET, */
 		TRUE,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
 
+		TRUE,	/* DATA_N_SWAP_PAGE_MBR, */
 		TRUE,	/* DATA_N_PREV_PAGE, */
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
@@ -847,6 +963,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 		FALSE,	/* DATA_N_STORE_LIGHT, */
+		TRUE,	/* DATA_N_GRAPH_FILE, */
 
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
@@ -897,6 +1014,34 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
+		FALSE,	/* DATA_N_SKILL_NAME_A, */
+		FALSE,	/* DATA_N_SKILL_NAME_B, */
+		FALSE,	/* DATA_N_SKILL_LEV, */
+		FALSE,	/* DATA_N_SKILL_EXP, */
+		FALSE,	/* DATA_N_SKILL_NEED_EXP, */
+
+		TRUE,	/* DATA_N_SKILL_A_00, */
+		TRUE,	/* DATA_N_SKILL_A_01, */
+		TRUE,	/* DATA_N_SKILL_A_02, */
+		TRUE,	/* DATA_N_SKILL_A_03, */
+		TRUE,	/* DATA_N_SKILL_A_04, */
+		TRUE,	/* DATA_N_SKILL_A_05, */
+		TRUE,	/* DATA_N_SKILL_A_06, */
+		TRUE,	/* DATA_N_SKILL_A_07, */
+		TRUE,	/* DATA_N_SKILL_A_08, */
+		TRUE,	/* DATA_N_SKILL_A_09, */
+
+		TRUE,	/* DATA_N_SKILL_B_00, */
+		TRUE,	/* DATA_N_SKILL_B_01, */
+		TRUE,	/* DATA_N_SKILL_B_02, */
+		TRUE,	/* DATA_N_SKILL_B_03, */
+		TRUE,	/* DATA_N_SKILL_B_04, */
+		TRUE,	/* DATA_N_SKILL_B_05, */
+		TRUE,	/* DATA_N_SKILL_B_06, */
+		TRUE,	/* DATA_N_SKILL_B_07, */
+		TRUE,	/* DATA_N_SKILL_B_08, */
+		TRUE,	/* DATA_N_SKILL_B_09, */
+
 		TRUE,	/* DATA_N_ITEM_00, */
 		TRUE,	/* DATA_N_ITEM_01, */
 		TRUE,	/* DATA_N_ITEM_02, */
@@ -928,6 +1073,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		TRUE,	/* DATA_N_EQUIP_FEET, */
 		TRUE,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
 
+		TRUE,	/* DATA_N_SWAP_PAGE_MBR, */
 		TRUE,	/* DATA_N_PREV_PAGE, */
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
@@ -935,134 +1081,173 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 
 /* СΥǡɽڡֹ */
 
+#define	P_NULL	0x00
+#define	P_ALL	0xff
+#define	P1	0x01
+#define	P2	0x02
+#define	P3	0x04
+#define	P4	0x08
+#define	P5	0x10
+#define	P6	0x20
+
 long	data_page_n_tab[] = {
-	0,	/* DATA_N_NULL, */
+	P_NULL,	/* DATA_N_NULL, */
 
-	0xff,	/* DATA_N_NAME, */
-	0x01,	/* DATA_N_FACE, */
-	0x01,	/* DATA_N_RACE_STR, */
-	0x01,	/* DATA_N_RACE_NAME, */
-	0x01,	/* DATA_N_SEX, */
+	P_ALL,	/* DATA_N_NAME, */
+	P1,	/* DATA_N_FACE, */
+	P1,	/* DATA_N_RACE_STR, */
+	P1,	/* DATA_N_RACE_NAME, */
+	P1,	/* DATA_N_SEX, */
 
-	0x01,	/* DATA_N_HP_VAL, */
-	0x01,	/* DATA_N_MP_VAL, */
+	P1,	/* DATA_N_HP_VAL, */
+	P1,	/* DATA_N_MP_VAL, */
 
-	0x01,	/* DATA_N_VAL_TTL, */
-	0x01,	/* DATA_N_HIT, */
-	0x01,	/* DATA_N_WPN_CRTCL, */
-	0x01,	/* DATA_N_DAM, */
-	0x01,	/* DATA_N_DEF, */
-	0x01,	/* DATA_N_ARMOR_CRTCL, */
-	0x01,	/* DATA_N_AC, */
-	0x01,	/* DATA_N_GOLD, */
-	0x01,	/* DATA_N_TURN, */
+	P1,	/* DATA_N_VAL_TTL, */
+	P1,	/* DATA_N_HIT, */
+	P1,	/* DATA_N_WPN_CRTCL, */
+	P1,	/* DATA_N_DAM, */
+	P1,	/* DATA_N_DEF, */
+	P1,	/* DATA_N_ARMOR_CRTCL, */
+	P1,	/* DATA_N_AC, */
+	P1,	/* DATA_N_GOLD, */
+	P1,	/* DATA_N_TURN, */
 
-	0x01,	/* DATA_N_STAT_TTL, */
-	0x01,	/* DATA_N_STAT_DEAD, */
-	0x01,	/* DATA_N_STAT_STONE, */
-	0x01,	/* DATA_N_STAT_PARALYZE, */
-	0x01,	/* DATA_N_STAT_POISON, */
-	0x01,	/* DATA_N_STAT_CONFUSION, */
-	0x01,	/* DATA_N_STAT_BLIND, */
-	0x01,	/* DATA_N_STAT_SLEEP, */
-	0x01,	/* DATA_N_STAT_SILENCE, */
-	0x01,	/* DATA_N_STAT_CAUGHT, */
-	0x01,	/* DATA_N_STAT_FEAR, */
-	0x01,	/* DATA_N_STAT_HALLUCINATION, */
-	0x01,	/* DATA_N_STAT_CHARM, */
-	0x01,	/* DATA_N_STAT_FLY, */
-	0x01,	/* DATA_N_STAT_HUNGRY, */
-	0x01,	/* DATA_N_STAT_FAINT, */
-	0x01,	/* DATA_N_STAT_DRUNK, */
-	0x01,	/* DATA_N_STAT_VANISH, */
-	0x01,	/* DATA_N_STAT_IRON_BODY, */
-	0x01,	/* DATA_N_STAT_PASSWALL, */
-	0x01,	/* DATA_N_STAT_SENSE_INVISIBLE, */
+	P1,	/* DATA_N_STAT_TTL, */
+	P1,	/* DATA_N_STAT_DEAD, */
+	P1,	/* DATA_N_STAT_STONE, */
+	P1,	/* DATA_N_STAT_PARALYZE, */
+	P1,	/* DATA_N_STAT_POISON, */
+	P1,	/* DATA_N_STAT_CONFUSION, */
+	P1,	/* DATA_N_STAT_BLIND, */
+	P1,	/* DATA_N_STAT_SLEEP, */
+	P1,	/* DATA_N_STAT_SILENCE, */
+	P1,	/* DATA_N_STAT_CAUGHT, */
+	P1,	/* DATA_N_STAT_FEAR, */
+	P1,	/* DATA_N_STAT_HALLUCINATION, */
+	P1,	/* DATA_N_STAT_CHARM, */
+	P1,	/* DATA_N_STAT_FLY, */
+	P1,	/* DATA_N_STAT_HUNGRY, */
+	P1,	/* DATA_N_STAT_FAINT, */
+	P1,	/* DATA_N_STAT_DRUNK, */
+	P1,	/* DATA_N_STAT_VANISH, */
+	P1,	/* DATA_N_STAT_IRON_BODY, */
+	P1,	/* DATA_N_STAT_PASSWALL, */
+	P1,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
-	0x01,	/* DATA_N_STORE_LIGHT, */
+	P1,	/* DATA_N_STORE_LIGHT, */
+	P1,	/* DATA_N_GRAPH_FILE, */
 
-	0x02,	/* DATA_N_LEV_LEFT, */
-	0x02,	/* DATA_N_EXP_LEFT, */
-	0x02,	/* DATA_N_NEED_EXP_LEFT, */
+	P2,	/* DATA_N_LEV_LEFT, */
+	P2,	/* DATA_N_EXP_LEFT, */
+	P2,	/* DATA_N_NEED_EXP_LEFT, */
 
-	0x02,	/* DATA_N_LEV_RIGHT, */
-	0x02,	/* DATA_N_EXP_RIGHT, */
-	0x02,	/* DATA_N_NEED_EXP_RIGHT, */
+	P2,	/* DATA_N_LEV_RIGHT, */
+	P2,	/* DATA_N_EXP_RIGHT, */
+	P2,	/* DATA_N_NEED_EXP_RIGHT, */
 
-	0x02,	/* DATA_N_HP, */
-	0x02,	/* DATA_N_MP, */
-	0x02,	/* DATA_N_DEX, */
-	0x02,	/* DATA_N_STR, */
-	0x02,	/* DATA_N_AGI, */
-	0x02,	/* DATA_N_INT, */
-	0x02,	/* DATA_N_WIS, */
-	0x02,	/* DATA_N_CHA, */
+	P2,	/* DATA_N_HP, */
+	P2,	/* DATA_N_MP, */
+	P2,	/* DATA_N_DEX, */
+	P2,	/* DATA_N_STR, */
+	P2,	/* DATA_N_AGI, */
+	P2,	/* DATA_N_INT, */
+	P2,	/* DATA_N_WIS, */
+	P2,	/* DATA_N_CHA, */
 
-	0x02,	/* DATA_N_RESI_TTL, */
-	0x02,	/* DATA_N_RESI_TTL_LAWFUL, */
-	0x02,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
-	0x02,	/* DATA_N_RESI_TTL_CHAOTIC, */
-	0x02,	/* DATA_N_RESI_TTL_GOOD, */
-	0x02,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
-	0x02,	/* DATA_N_RESI_TTL_EVIL, */
-	0x02,	/* DATA_N_RESI_KNOC, */
-	0x02,	/* DATA_N_RESI_SLAS, */
-	0x02,	/* DATA_N_RESI_STIN, */
-	0x02,	/* DATA_N_RESI_HEAT, */
-	0x02,	/* DATA_N_RESI_COLD, */
-	0x02,	/* DATA_N_RESI_MIND, */
-	0x02,	/* DATA_N_RESI_ACID, */
-	0x02,	/* DATA_N_RESI_ELEC, */
-	0x02,	/* DATA_N_RESI_POIS, */
+	P2,	/* DATA_N_RESI_TTL, */
+	P2,	/* DATA_N_RESI_TTL_LAWFUL, */
+	P2,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
+	P2,	/* DATA_N_RESI_TTL_CHAOTIC, */
+	P2,	/* DATA_N_RESI_TTL_GOOD, */
+	P2,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
+	P2,	/* DATA_N_RESI_TTL_EVIL, */
+	P2,	/* DATA_N_RESI_KNOC, */
+	P2,	/* DATA_N_RESI_SLAS, */
+	P2,	/* DATA_N_RESI_STIN, */
+	P2,	/* DATA_N_RESI_HEAT, */
+	P2,	/* DATA_N_RESI_COLD, */
+	P2,	/* DATA_N_RESI_MIND, */
+	P2,	/* DATA_N_RESI_ACID, */
+	P2,	/* DATA_N_RESI_ELEC, */
+	P2,	/* DATA_N_RESI_POIS, */
 
-	0x02,	/* DATA_N_CLASS, */
+	P2 | P3 | P4,	/* DATA_N_CLASS, */
 
-	0x02,	/* DATA_N_FIG, */
-	0x02,	/* DATA_N_MON, */
-	0x02,	/* DATA_N_HUN, */
-	0x02,	/* DATA_N_THI, */
-	0x02,	/* DATA_N_MAG, */
-	0x02,	/* DATA_N_SOR, */
-	0x02,	/* DATA_N_ENC, */
-	0x02,	/* DATA_N_SUM, */
-	0x02,	/* DATA_N_PRI, */
-	0x02,	/* DATA_N_SHA, */
-	0x02,	/* DATA_N_BAR, */
-	0x02,	/* DATA_N_NIN, */
+	P2,	/* DATA_N_FIG, */
+	P2,	/* DATA_N_MON, */
+	P2,	/* DATA_N_HUN, */
+	P2,	/* DATA_N_THI, */
+	P2,	/* DATA_N_MAG, */
+	P2,	/* DATA_N_SOR, */
+	P2,	/* DATA_N_ENC, */
+	P2,	/* DATA_N_SUM, */
+	P2,	/* DATA_N_PRI, */
+	P2,	/* DATA_N_SHA, */
+	P2,	/* DATA_N_BAR, */
+	P2,	/* DATA_N_NIN, */
 
-	0x04,	/* DATA_N_ITEM_00, */
-	0x04,	/* DATA_N_ITEM_01, */
-	0x04,	/* DATA_N_ITEM_02 */
-	0x04,	/* DATA_N_ITEM_03, */
-	0x04,	/* DATA_N_ITEM_04 */
-	0x04,	/* DATA_N_ITEM_05, */
-	0x04,	/* DATA_N_ITEM_06, */
-	0x04,	/* DATA_N_ITEM_07, */
-	0x04,	/* DATA_N_ITEM_08, */
-	0x04,	/* DATA_N_ITEM_09, */
-	0x04,	/* DATA_N_ITEM_10, */
-	0x04,	/* DATA_N_ITEM_11, */
-	0x04,	/* DATA_N_ITEM_12 */
-	0x04,	/* DATA_N_ITEM_13, */
-	0x04,	/* DATA_N_ITEM_14 */
-	0x04,	/* DATA_N_ITEM_15, */
+	P3,	/* DATA_N_SKILL_NAME_A, */
+	P4,	/* DATA_N_SKILL_NAME_B, */
+	P3 | P4,	/* DATA_N_SKILL_LEV, */
+	P3 | P4,	/* DATA_N_SKILL_EXP, */
+	P3 | P4,	/* DATA_N_SKILL_NEED_EXP, */
 
-	0x08,	/* DATA_N_EQUIP_WIELDING, */
-	0x08,	/* DATA_N_EQUIP_SHIELD, */
-	0x08,	/* DATA_N_EQUIP_BOW, */
-	0x08,	/* DATA_N_EQUIP_ARW, */
-	0x08,	/* DATA_N_EQUIP_HEAD, */
-	0x08,	/* DATA_N_EQUIP_NECK, */
-	0x08,	/* DATA_N_EQUIP_BODY, */
-	0x08,	/* DATA_N_EQUIP_ABOUT_BODY, */
-	0x08,	/* DATA_N_EQUIP_ARM, */
-	0x08,	/* DATA_N_EQUIP_RIGHT_HAND, */
-	0x08,	/* DATA_N_EQUIP_LEFT_HAND, */
-	0x08,	/* DATA_N_EQUIP_FEET, */
-	0x08,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
+	P3,	/* DATA_N_SKILL_A_00, */
+	P3,	/* DATA_N_SKILL_A_01, */
+	P3,	/* DATA_N_SKILL_A_02, */
+	P3,	/* DATA_N_SKILL_A_03, */
+	P3,	/* DATA_N_SKILL_A_04, */
+	P3,	/* DATA_N_SKILL_A_05, */
+	P3,	/* DATA_N_SKILL_A_06, */
+	P3,	/* DATA_N_SKILL_A_07, */
+	P3,	/* DATA_N_SKILL_A_08, */
+	P3,	/* DATA_N_SKILL_A_09, */
 
-	0xff,	/* DATA_N_PREV_PAGE, */
-	0xff,	/* DATA_N_NEXT_PAGE, */
+	P4,	/* DATA_N_SKILL_B_00, */
+	P4,	/* DATA_N_SKILL_B_01, */
+	P4,	/* DATA_N_SKILL_B_02, */
+	P4,	/* DATA_N_SKILL_B_03, */
+	P4,	/* DATA_N_SKILL_B_04, */
+	P4,	/* DATA_N_SKILL_B_05, */
+	P4,	/* DATA_N_SKILL_B_06, */
+	P4,	/* DATA_N_SKILL_B_07, */
+	P4,	/* DATA_N_SKILL_B_08, */
+	P4,	/* DATA_N_SKILL_B_09, */
+
+	P5,	/* DATA_N_ITEM_00, */
+	P5,	/* DATA_N_ITEM_01, */
+	P5,	/* DATA_N_ITEM_02 */
+	P5,	/* DATA_N_ITEM_03, */
+	P5,	/* DATA_N_ITEM_04 */
+	P5,	/* DATA_N_ITEM_05, */
+	P5,	/* DATA_N_ITEM_06, */
+	P5,	/* DATA_N_ITEM_07, */
+	P5,	/* DATA_N_ITEM_08, */
+	P5,	/* DATA_N_ITEM_09, */
+	P5,	/* DATA_N_ITEM_10, */
+	P5,	/* DATA_N_ITEM_11, */
+	P5,	/* DATA_N_ITEM_12 */
+	P5,	/* DATA_N_ITEM_13, */
+	P5,	/* DATA_N_ITEM_14 */
+	P5,	/* DATA_N_ITEM_15, */
+
+	P6,	/* DATA_N_EQUIP_WIELDING, */
+	P6,	/* DATA_N_EQUIP_SHIELD, */
+	P6,	/* DATA_N_EQUIP_BOW, */
+	P6,	/* DATA_N_EQUIP_ARW, */
+	P6,	/* DATA_N_EQUIP_HEAD, */
+	P6,	/* DATA_N_EQUIP_NECK, */
+	P6,	/* DATA_N_EQUIP_BODY, */
+	P6,	/* DATA_N_EQUIP_ABOUT_BODY, */
+	P6,	/* DATA_N_EQUIP_ARM, */
+	P6,	/* DATA_N_EQUIP_RIGHT_HAND, */
+	P6,	/* DATA_N_EQUIP_LEFT_HAND, */
+	P6,	/* DATA_N_EQUIP_FEET, */
+	P6,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
+
+	P_ALL,	/* DATA_N_SWAP_PAGE_MBR, */
+	P_ALL,	/* DATA_N_PREV_PAGE, */
+	P_ALL,	/* DATA_N_NEXT_PAGE, */
 };
 
 /* § */
