@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.h,v 1.32 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: fight.h,v 1.36 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FIGHT_H
@@ -73,6 +73,9 @@ typedef enum {
 	ATTACK_KIND_CARESS_BUST,	/* 򿨤 */
 	ATTACK_KIND_CARESS_HIP,	/* Ǥ */
 	ATTACK_KIND_CARESS_CROTCH,	/* Դ֤Ǥ */
+	ATTACK_KIND_CYBERN_PUNCH,	/* ҥѥ */
+	ATTACK_KIND_CYBERN_KICK,	/* ҥå */
+	ATTACK_KIND_XX_SLAP,	/* ʿǤ */
 	ATTACK_KIND_MAX_N,
 } attack_kind_t;
 
