@@ -220,6 +220,8 @@ bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
 bool_t	load_game_conf_move_crsr_dflt( char *id, long val );
+bool_t	load_game_conf_music_volume( char *id, long val );
+bool_t	load_game_conf_sound_volume( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
 bool_t	load_game_conf_gnome( char *id, long val );
 bool_t	load_game_conf_set_window_position( char *id, long val );
@@ -273,6 +275,7 @@ bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_sound( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_joystick( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_vfx( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_color( FILE *fp, const ver_t *ver );
