@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.69 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: gmain.h,v 1.72 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -225,6 +225,15 @@ EXTERN long	g_randm_seed_save;
 /* ƥμϤλ񤹤 */
 EXTERN bool_t	g_flg_send_item_exec_turn;
 
+/* åȡΥǥ򥹥åפ뤫? */
+EXTERN bool_t	g_flg_skip_demo_cut_in;
+
+/* ο CUI */
+EXTERN long	g_cui_star_n;
+
+/* ο GUI */
+EXTERN long	g_gui_star_n;
+
 /* ǥХå⡼ */
 EXTERN bool_t	g_flg_debug;
 
