@@ -86,6 +86,9 @@ char	*cb_menu_item_fill_lamp( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_ready_throw( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_send( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt );
+char	*cb_menu_item_put_in_chest( menu_t **pp, menu_t **dflt );
+char	*cb_menu_item_ls_chest( menu_t **pp, menu_t **dflt );
+char	*cb_menu_chest_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_alias( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_chk( menu_t **pp, menu_t **dflt );
