@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.52 2009/09/13 17:48:24 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.57 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -1140,7 +1140,43 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/gui/replay music",
+		"/misc/config/gui/sound",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_SOUND, "",
+		cb_menu_sound, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/sound/sound volume",
+		"<OpenWinItem>",
+		'S',
+		"",
+		N_MSG_MENU_SOUND_VOLUME, "",
+		cb_menu_sound_volume, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/sound/music volume",
+		"<OpenWinItem>",
+		'M',
+		"",
+		N_MSG_MENU_MUSIC_VOLUME, "",
+		cb_menu_music_volume, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/sound/mute",
+		"<CheckItem>",
+		'U',
+		"",
+		N_MSG_MENU_MUTE_SOUND, "",
+		cb_menu_mute_sound, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/sound/replay music",
 		"<Item>",
 		'R',
 		"p",
@@ -2035,6 +2071,7 @@ menu_t	ls_menu_mark_trap[] = {
 };
 
 menu_t	ls_menu_item[MBR_ITEM_MAX_N * 2 * MBR_MAX_N];
+menu_t	ls_menu_chest[1 + 1 + CHEST_HOLD_MAX_N + 1];
 
 menu_t	ls_menu_item_sel[] = {
 	{
@@ -2154,6 +2191,24 @@ menu_t	ls_menu_item_sel[] = {
 		cb_menu_item_receive, NULL,
 		FLG_NULL,
 	},
+	{
+		"/item sel/put in chest",
+		"<OpenWinItem>",
+		'U',
+		"",
+		N_MSG_MENU_ITEM_PUT_IN_CHEST, "",
+		cb_menu_item_put_in_chest, NULL,
+		FLG_NULL,
+	},
+	{
+		"/item sel/list chest",
+		"<OpenWinItem>",
+		'L',
+		"",
+		N_MSG_MENU_ITEM_LS_CHEST, "",
+		cb_menu_item_ls_chest, NULL,
+		FLG_NULL,
+	},
 	{
 		"/item sel/drop",
 		"<OpenWinItem>",
