@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.209 2009/09/04 11:35:11 bowkenken Exp $
+* $Id: spell.c,v 1.212 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -728,13 +728,19 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 
 	if( !chk_can_chr_cast_lev( g_sel_mbr, g_sel_spell->kind ) ){
+		curs_attrset_chr( g_sel_mbr, -1, FALSE );
 		print_msg( FLG_NULL, MSG_ERR_MENU_SPELL_LEV,
 				g_sel_mbr->name );
+		curs_attrset_dflt();
+
 		return STR_MENU_CANCEL;
 	}
 
 	if( !chk_last_boss_can_spell( g_sel_spell->kind ) ){
+		curs_attrset_chr( g_sel_mbr, -1, FALSE );
 		print_msg( FLG_NULL, MSG_ERR_MENU_SPELL_LAST_BOSS );
+		curs_attrset_dflt();
+
 		return STR_MENU_CANCEL;
 	}
 
@@ -2018,6 +2024,7 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_ANIMATE_OBJECTS:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_SHELTER:
 		fx_shelter( x, y );
@@ -2038,8 +2045,11 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_ANALYZE_DWEOMER:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_DETECT_MAGIC:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_DETECT_ITEM:
 		fx_detect_item( chr );
@@ -2059,6 +2069,7 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_FEATHER_FALL:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_VANISH:
 		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
@@ -2071,17 +2082,22 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_DISPEL_MAGIC:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_MIRROR_IMAGE:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_POLYMORPH_OTHER:
 		fx_polymorph( (chr_t *)p );
 		break;
 	case SPELL_KIND_POLYMORPH_SELF:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_STEALTH:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_MAG_MAX_N:
 		break;
@@ -2130,12 +2146,14 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_STONESKIN:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_IRON_BODY:
 		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_SPELL_RESISTANCE:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_COUNTER_MAGIC:
 		fx_std( (chr_t *)p, FX_KIND_COUNTER_MAGIC );
@@ -2216,8 +2234,11 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_HUNGER:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_CANCELLATION:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_ENC_MAX_N:
 		break;
@@ -2250,9 +2271,11 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_SUMMON_RANDOM:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_CREATE_UNDEAD:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_DISMISSAL:
 		fx_dismissal( (chr_t *)p );
@@ -2277,12 +2300,14 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_CURE_MP:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_TRANSFER_MP:
 		fx_transfer_mp( (chr_t *)p, tab, rate );
 		break;
 	case SPELL_KIND_REGENERATION:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_RESTORE_EXPERIENCE:
 		fx_cure_exp( (chr_t *)p );
@@ -2328,6 +2353,7 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_PROTECTION:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_RESIST_PHYSICAL:
 		fx_resi( (chr_t *)p, FX_KIND_RESI_KNOC );
