@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,19 +25,27 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.61 2009/08/15 07:08:07 bowkenken Exp $
+* $Id: ver.h,v 1.63 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
 #define	VER_H
 
-#define	STR_FILE_NAME_GAME	"lnl"
+#if	defined( D_WS ) || defined( D_GTK )
+# define	STR_FILE_NAME_GAME	"xlnl"
+#elif	defined( D_MFC )
+# define	STR_FILE_NAME_GAME	"xlnl-dows"
+#elif	defined( D_DOS )
+# define	STR_FILE_NAME_GAME	"lnl-dos"
+#else
+# define	STR_FILE_NAME_GAME	"lnl"
+#endif
 
 #define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
 #define	STR_VER_GAME	VERSION
 
 #define	STR_SINCE	"1993"
-#define	STR_LATEST	"2009"
+#define	STR_LATEST	"2010"
 #define	STR_AUTHOR	"YOSHIMURA, Tomohiko"
 
 #define	STR_WEB	"http://lnl.sourceforge.jp/"
